@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
-# Full tag list for any given file.
 # Copyright 2005 Joe Wreschnig
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of version 2 of the GNU General Public License as
-# published by the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+"""Full tag list for any given file."""
 
 from mutagen._senf import print_, argv
-from mutagen._compat import text_type
 
 from ._util import SignalHandler, OptionParser
 
@@ -34,7 +35,7 @@ def main(argv):
         except AttributeError:
             print_(u"- Unknown file type")
         except Exception as err:
-            print_(text_type(err))
+            print_(str(err))
         print_(u"")
 
 
